==> checker-3.14.0.jar: annotated-jdk/src/java.base/share/classes/java/nio/StringCharBuffer.java <==
/*
 * Copyright (c) 2000, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package java.nio;

import org.checkerframework.checker.nullness.qual.EnsuresNonNullIf;
import org.checkerframework.checker.nullness.qual.NonNull;
import org.checkerframework.checker.nullness.qual.Nullable;
import org.checkerframework.dataflow.qual.Pure;
import org.checkerframework.dataflow.qual.SideEffectFree;

class StringCharBuffer extends CharBuffer {

    public CharBuffer slice();

    public CharBuffer duplicate();

    public CharBuffer asReadOnlyBuffer();

    public final char get();

    public final char get(int index);

    char getUnchecked(int index);

    public final CharBuffer put(char c);

    public final CharBuffer put(int index, char c);

    public final CharBuffer compact();

    public final boolean isReadOnly();

    final String toString(int start, int end);

    public final CharBuffer subSequence(int start, int end);

    public boolean isDirect();

    public ByteOrder order();

    ByteOrder charRegionOrder();

    @Pure
    @EnsuresNonNullIf(expression = "#1", result = true)
    public boolean equals(@Nullable Object ob);

    public int compareTo(CharBuffer that);
}

==> checker-3.53.1.jar: annotated-jdk/src/java.base/share/classes/java/nio/StringCharBuffer.java <==
/*
 * Copyright (c) 2000, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package java.nio;

import org.checkerframework.checker.nullness.qual.EnsuresNonNullIf;
import org.checkerframework.checker.nullness.qual.NonNull;
import org.checkerframework.checker.nullness.qual.Nullable;
import org.checkerframework.dataflow.qual.Pure;
import org.checkerframework.dataflow.qual.SideEffectFree;
import java.util.Objects;

final class StringCharBuffer extends CharBuffer {

    public CharBuffer slice();

    @Override
    public CharBuffer slice(int index, int length);

    public CharBuffer duplicate();

    public CharBuffer asReadOnlyBuffer();

    public final char get();

    public final char get(int index);

    char getUnchecked(int index);

    public final CharBuffer put(char c);

    public final CharBuffer put(int index, char c);

    public final CharBuffer compact();

    public final boolean isReadOnly();

    final String toString(int start, int end);

    public final CharBuffer subSequence(int start, int end);

    public boolean isDirect();

    public ByteOrder order();

    ByteOrder charRegionOrder();

    boolean isAddressable();

    @Pure
    @EnsuresNonNullIf(expression = "#1", result = true)
    public boolean equals(@Nullable Object ob);

    public int compareTo(CharBuffer that);
}
